@@ -58,6 +58,7 @@ from google.cloud.vpcaccess_v1.types import vpc_access
 from .transports.base import DEFAULT_CLIENT_INFO, VpcAccessServiceTransport
 from .transports.grpc import VpcAccessServiceGrpcTransport
 from .transports.grpc_asyncio import VpcAccessServiceGrpcAsyncIOTransport
+from .transports.rest import VpcAccessServiceRestTransport
 
 
 class VpcAccessServiceClientMeta(type):
@@ -73,6 +74,7 @@ class VpcAccessServiceClientMeta(type):
     )  # type: Dict[str, Type[VpcAccessServiceTransport]]
     _transport_registry["grpc"] = VpcAccessServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = VpcAccessServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = VpcAccessServiceRestTransport
 
     def get_transport_class(
         cls,
@@ -497,8 +499,8 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
 
         Args:
             request (Union[google.cloud.vpcaccess_v1.types.CreateConnectorRequest, dict]):
-                The request object. Request for creating a Serverless
-                VPC Access connector.
+                The request object. Request for creating a Serverless VPC
+                Access connector.
             parent (str):
                 Required. The project and location in which the
                 configuration should be created, specified in the format
@@ -850,8 +852,8 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
 
         Args:
             request (Union[google.cloud.vpcaccess_v1.types.DeleteConnectorRequest, dict]):
-                The request object. Request for deleting a Serverless
-                VPC Access connector.
+                The request object. Request for deleting a Serverless VPC
+                Access connector.
             name (str):
                 Required. Name of a Serverless VPC
                 Access connector to delete.
